Learn R Programming

ggfields (version 0.0.7)

seawatervelocity: A small subset of the global ocean physics analysis and forecast product

Description

A small subset of ocean currents data retrieved with CopernicusMarine from the source listed below serving as an example.

Arguments

Format

A stars object with x, y, depth and time dimensions. It has the attributes vo (northward seawater velocity [m/s]) and uo (eastward seawater velocity [m/s]).

References

E.U. Copernicus Marine Service Information; Global Ocean Physics Analysis and Forecast - GLOBAL_ANALYSISFORECAST_PHY_001_024 (2016-10-14). tools:::Rd_expr_doi("DOI:10.48670/moi-00016")

Examples

Run this code
data("seawatervelocity")

Run the code above in your browser using DataLab